import { Inject, Injectable } from '@nestjs/common';
import { ClientProxy } from '@nestjs/microservices';
import { FisMessage } from 'libs';
import { Observable, Subject } from 'rxjs';

@Injectable()
export class SampleAppService {
  private fingerprintMessage: Subject<FisMessage> = new Subject()

  constructor(
    @Inject(`FINGERPRINT_SERVICE`) private fingerprintClient: ClientProxy,
    @Inject(`VERIFICATION_SERVICE`) private verificationClient: ClientProxy
  ) {
    // logic here
  }

  getHello(): string {
    return 'Hello World! I am Sample App Nestjs.';
  }

  // testing. Try to talk to Fingerprint App via microservice
  talkToFingerprint(message: string): any {
    this.fingerprintClient.emit<string>(`eventTest`, message)
    this.verificationClient.emit<string>(`eventTest`, message)
    return this.fingerprintClient.send<string>({ cmd: `messageTest` }, message)
  }

  emit(data: any): void {
    this.fingerprintClient.emit(`message`, data)
  }

  getFingerprintMessages(): Observable<FisMessage> {
    return this.fingerprintMessage.asObservable()
  }

  emitFpResponse(message: FisMessage): void {
    this.fingerprintMessage.next(message)
  }
}
